



local LevelScene = {}

local mainLayer

local batchNode
local frameCache
local levelIcons = {}




--可视范围
local visibleSize = CCDirector:sharedDirector():getVisibleSize()

--原始范围
local origin = CCDirector:sharedDirector():getVisibleOrigin()


-- create mainLayer
local function createLayer()
	mainLayer = CCLayer:create()
	batchNode = CCSpriteBatchNode:create("img/level/level.png")	
	frameCache  = CCSpriteFrameCache:sharedSpriteFrameCache()
	frameCache:removeSpriteFrames()	
	frameCache:addSpriteFramesWithFile("img/level/level.plist")
	-- add in farm background
	local bg = CCSprite:create("img/level/levelBg.jpg")
	bg:setPosition(origin.x + visibleSize.width / 2 , origin.y + visibleSize.height / 2)
	
	mainLayer:addChild(bg)
	mainLayer:addChild(batchNode)

	local backButton = CCSprite:create("img/buttons/back.png")
	local backButtonSize = backButton:getContentSize()
	backButton:setPosition(10+backButtonSize.width/2,Common.visibleSize.height-backButtonSize.height/2-10)
	mainLayer:addChild(backButton)

	local levelNumber = 20
	local lineNumber = levelNumber/5
	local area = {}
	local gridConfig={}
	local gridOriSize={width=100,height=100}
	area.width = Common.visibleSize.width-20
	area.height = area.width
	area.xNum = 4
	area.yNum = 5	
	--标定格子参数
	
	gridConfig.width = area.width/area.xNum
	gridConfig.height=gridConfig.width

	--以上参数以后从全局配置获取
	--原始格子的缩放比例
	scale = gridConfig.width/gridOriSize.width
	local startX = (Common.visibleSize.width - area.width)/2
	local startY = 100
	local mission = CCUserDefault:sharedUserDefault():getIntegerForKey("curMission")
	local maxOpenLevel = CCUserDefault:sharedUserDefault():getIntegerForKey("mission"..mission.."_maxOpenLevel")
	local levelIconSprite
	local img = "levelLock.png"
	for j=1,area.yNum do
		for i=1,area.xNum do
			local isLock = 1
			local levelOrder = (j-1)*4+i		
			if maxOpenLevel==0 and i==1 and j==1  then 
				img = "levelIcon.png"
				isLock = 0
			elseif levelOrder <= maxOpenLevel then
				img = "levelIcon.png"
				isLock = 0
			else 
				img = "levelLock.png"		
			end 
			levelIconSprite= CCSprite:createWithSpriteFrameName(img)
			levelIconSprite:setScale(scale)
			local iconSize = levelIconSprite:getContentSize()	
			levelIconSprite:setPosition(startX+gridConfig.width*(i+0.5-1),startY+(gridConfig.height+10)*(j+0.5-1))					
			batchNode:addChild(levelIconSprite)
			levelIcons[#levelIcons+1]={}
			levelIcons[#levelIcons]["sprite"] = levelIconSprite
			levelIcons[#levelIcons]["levelOrder"] = levelOrder
			levelIcons[#levelIcons]["isLock"] = isLock
			if img == "levelIcon.png" then 
				local label = CCLabelTTF:create (levelOrder, "Marker Felt", Common.config["buttonFontSize"])	
				label:setPosition(levelIconSprite:getPositionX(),levelIconSprite:getPositionY())
				mainLayer:addChild(label)	
			end 										
		end 
	end 

	mainLayer:setKeypadEnabled(true)
	mainLayer:registerScriptKeypadHandler(function(callback) Common.keyEventListener(callback) end) 

	local backButtonBindBox = backButton:boundingBox()

	-- handing touch events
	local touchBeginPoint = nil

	local function onTouchBegan(x, y)			
  		local touchP = ccp(x,y) 
		return true
	end

	local function onTouchMoved(x, y)

	end

	local function onTouchEnded(x, y)
		local touchP = ccp(x,y)
		local mission = CCUserDefault:sharedUserDefault():getIntegerForKey("curMission")		
		for key,value in ipairs(levelIcons) do
			local iconSprite = value["sprite"]
			local positionx,positiony =iconSprite:getPosition()
			local worldPosition = iconSprite:getParent():convertToWorldSpace(ccp(positionx,positiony)) 
			local iconSize = iconSprite:getContentSize()
			local rect = CCRectMake(worldPosition.x - iconSize.width/2, worldPosition.y - iconSize.height/2,iconSize.width, iconSize.height) 
        	if rect:containsPoint(touchP) and  value["isLock"]== 0 then 
        		CCUserDefault:sharedUserDefault():setIntegerForKey("mission"..mission.."_curLevel",value["levelOrder"])       		
        		CCUserDefault:sharedUserDefault():flush()
        		local scene = MainScene.createScene()
				local transitionFade  = CCTransitionFade:create(1,scene) 
				CCDirector:sharedDirector():replaceScene(transitionFade)
        	end
		end 

		if backButtonBindBox:containsPoint(touchP) then 
			local mssionScene = MissionScene.createScene()
			local transitionFade  = CCTransitionFade:create(1,mssionScene) 
			CCDirector:sharedDirector():replaceScene(transitionFade)
		end 
	end

	local function onTouch(eventType, x, y)
		if eventType == "began" then
			return onTouchBegan(x, y)
			elseif eventType == "moved" then
			return onTouchMoved(x, y)
			else
			return onTouchEnded(x, y)
		end
	end

	mainLayer:registerScriptTouchHandler(onTouch)
	mainLayer:setTouchEnabled(true)
	
	return mainLayer
end

local function init()
	levelIcons = {}
end

function LevelScene.createScene()
	init()
	local scene = CCScene:create()
	scene:addChild(createLayer())
	CCDirector:sharedDirector():replaceScene(scene)
	return scene
end

--将successScene注册到全局对象表中
local modename = "LevelScene"
local proxy = {}
local mt    = {
    __index = LevelScene,
    __newindex =  function (t ,k ,v)
        print("attemp to update a read-only table")
    end
} 
setmetatable(proxy,mt)
_G[modename] = proxy
package.loaded[modename] = proxy


