require "common"
require "mainscene"
require "levelscene"
require "missionscene"
require "helpscene"




local StartScene = {}

local mainLayer

local isCloseSound
local startEffectPath



-- create mainLayer
local function createStartLayer()

	local bg = CCSprite:create("img/start.jpg")
	bg:setPosition(Common.visibleSize.width / 2 ,Common.visibleSize.height / 2)
	mainLayer = CCLayer:create()
	mainLayer:addChild(bg)

	local playButton = CCSprite:create("img/buttons/play.png")
	playButton:setPosition(Common.visibleSize.width / 2 ,Common.visibleSize.height / 2)
	mainLayer:addChild(playButton)

	local startX = (Common.visibleSize.width -200)/2

	local isCloseSound = CCUserDefault:sharedUserDefault():getIntegerForKey("isCloseSound")
	local soundImg
	if isCloseSound == 0 then 
		soundImg = "img/buttons/sound_open.png"
	else 
		soundImg = "img/buttons/sound_close.png"
	end 
	local soundButton = CCSprite:create(soundImg)
	soundButton:setPosition(Common.visibleSize.width - 60,Common.visibleSize.height -60 - 10)
	mainLayer:addChild(soundButton)

	local helpButton = CCSprite:create("img/buttons/help.png")
	helpButton:setPosition(Common.visibleSize.width - 60,Common.visibleSize.height - 60*2 - 10-10)
	mainLayer:addChild(helpButton)

	mainLayer:setKeypadEnabled(true)
	mainLayer:registerScriptKeypadHandler(function(callback) Common.keyEventListener(callback) end) 

	local playButtonBindBox = playButton:boundingBox()
	local soundButtonBindBox = soundButton:boundingBox()
	local helpButtonBindBox = helpButton:boundingBox()
	local function onTouchBegan(x, y)			
		return true
	end

	local function onTouchMoved(x, y)

	end

	local function onTouchEnded(x, y)		
		local touchP = ccp(x,y)
		if playButtonBindBox:containsPoint(touchP) then 
			local mainScene = MissionScene.createScene()
			local transitionFade  = CCTransitionFade:create(1,mainScene) 
			CCDirector:sharedDirector():replaceScene(transitionFade)
		end 

		if soundButtonBindBox:containsPoint(touchP) then 
			local isCloseSound = CCUserDefault:sharedUserDefault():getIntegerForKey("isCloseSound")
			if isCloseSound == 0 then
				AudioEngine.stopMusic(false)
				Common.changeButtonImage(soundButton,"img/buttons/sound_close.png")
				CCUserDefault:sharedUserDefault():setIntegerForKey("isCloseSound",1)							
			else 
				AudioEngine.playMusic(startEffectPath,true)
				Common.changeButtonImage(soundButton,"img/buttons/sound_open.png")
				CCUserDefault:sharedUserDefault():setIntegerForKey("isCloseSound",0)	
			end 
		end  


		if helpButtonBindBox:containsPoint(touchP) then 
			local mainScene = HelpScene.createScene()
			local transitionFade  = CCTransitionFade:create(1,mainScene) 
			CCDirector:sharedDirector():replaceScene(transitionFade)
		end 
	end

	local function onTouch(eventType, x, y)
		if eventType == "began" then
			return onTouchBegan(x, y)
			elseif eventType == "moved" then
			return onTouchMoved(x, y)
			else
			return onTouchEnded(x, y)
		end
	end

	mainLayer:registerScriptTouchHandler(onTouch)
	mainLayer:setTouchEnabled(true)
	return mainLayer
end
local function init()
	local isNewLinkTips = CCUserDefault:sharedUserDefault():getIntegerForKey("isNewLinkTips")
	if isNewLinkTips ~=1 then 
		isNewLinkTips = 1
		CCUserDefault:sharedUserDefault():setIntegerForKey("isNewLinkTips",isNewLinkTips)
		CCUserDefault:sharedUserDefault():setIntegerForKey("showLinkTips",3)
		CCUserDefault:sharedUserDefault():flush()
	end 
end 

function StartScene.createScene()

	local scene = CCScene:create()
	scene:addChild(createStartLayer())
	Common.runScene(scene)
	init()
	startEffectPath = CCFileUtils:sharedFileUtils():fullPathForFilename("sound/start.mp3")
	local isCloseSound = CCUserDefault:sharedUserDefault():getIntegerForKey("isCloseSound")
	AudioEngine.preloadMusic(startEffectPath)
	if isCloseSound == 0 then 
		AudioEngine.playMusic(startEffectPath,true)
	end 
	return scene
end

local function main()
	-- avoid memory leak
	collectgarbage("setpause", 100)
	collectgarbage("setstepmul", 5000)
	StartScene.createScene()
end



--将successScene注册到全局对象表中
local modename = "StartScene"
local proxy = {}
local mt    = {
    __index = StartScene,
    __newindex =  function (t ,k ,v)
        print("attemp to update a read-only table")
    end
} 
setmetatable(proxy,mt)
_G[modename] = proxy
package.loaded[modename] = proxy

--执行mian，启动游戏
xpcall(main, Common.__G__TRACKBACK__)



